# eric7.JediInterface

Package implementing the jedi assistant interface.

This package implements just the interface for the eric7 IDE. The underlying functionality is provided by the jedi library ( https://github.com/davidhalter/jedi).

### Modules

AssistantJedi | Module implementing the Jedi assistant plug-in.
JediClient | Module implementing the Jedi client of eric7.
JediServer | Module implementing the autocompletion interface to jedi.
RefactoringPreviewDialog | Module implementing a dialog to preview refactoring changes.